@@ -15,6 +15,10 @@ from rabbitmq_alphamoon.logger import get_logger
 LOGGER = get_logger('rabbitmq_alphamoon')
 
 
+class ProcessingInterrupt(Exception):
+    pass
+
+
 class IQueueConnector(metaclass=abc.ABCMeta):
     @contextmanager
     def open_connection(self) -> Iterator[RabbitMQConnector]:
@@ -252,13 +256,17 @@ class RabbitMQConnector(IQueueConnector):
                     raise
 
                 info = {}
+                properties_header = properties.headers or {}
+
                 if self._requeue:
                     info['redelivered'] = deliver.redelivered
+
                 if self._dead_letter_exchange:
-                    properties_header = properties.headers or {}
                     x_death_header = properties_header.get('x-death', [{}])[0]
                     info['dlx_retry_count'] = x_death_header.get('count', 0)
                     info['dlx_last_fail_reason'] = x_death_header.get('reason')
+
+                if self._quorum:
                     info['quorum-delivery-count'] = properties_header.get('x-delivery-count', 0)
 
                 try:
@@ -299,7 +307,11 @@ class RabbitMQConnector(IQueueConnector):
 
             # Running the processing in separate thread allow for connection keep-alive as the main
             # thread is not being blocked by the processing.
-            Thread(target=process_fun, name=f'message # {tag}, queue {self._queue}').start()
+            Thread(
+                target=process_fun,
+                name=f'message # {tag}, queue {self._queue}',
+                daemon=True,
+            ).start()
 
         try:
             while True:
@@ -319,6 +331,12 @@ class RabbitMQConnector(IQueueConnector):
                     LOGGER.warning("%s, queue %s: %s, retrying...", error_type, self._queue, error)
                     time.sleep(1)
                     connection = self._reconnect_and_get_opened_connection()
+                except pika.exceptions.ChannelClosedByBroker as error:
+                    error_type = type(error).__name__  # 'ChannelClosedByBroker'
+                    LOGGER.error(
+                        "%s, queue %s: %s, interrupting...", error_type, self._queue, error
+                    )
+                    raise ProcessingInterrupt from error
                 except pika.exceptions.AMQPChannelError as error:
                     error_type = type(error).__name__  # e.g. 'ChannelWrongStateError'
                     LOGGER.error("%s, queue %s: %s, stopping...", error_type, self._queue, error)
